@@ -7,7 +7,7 @@ _logger = logging.getLogger(__name__)
 # This will be assigned from the top of the "rijndael" package.
 rijndael_cls = None
 
-def rjindael_encrypt_gen(key, s, block_size=pprp.config.DEFAULT_BLOCK_SIZE):
+def rjindael_encrypt_gen(key, s, block_size=pprp.config.DEFAULT_BLOCK_SIZE_B):
     r = rijndael_cls(key, block_size=block_size)
 
     padded = False
@@ -16,7 +16,7 @@ def rjindael_encrypt_gen(key, s, block_size=pprp.config.DEFAULT_BLOCK_SIZE):
         len_ = len(block)
         if len_ < block_size:
             padding_size = block_size - len_
-            block += (chr(padding_size) * padding_size)
+            block += (chr(padding_size) * padding_size).encode('ASCII')
             padded = True
 
         _logger.debug("Encrypting and yielding encrypted block: (%d) (%d)", 
@@ -28,7 +28,7 @@ def rjindael_encrypt_gen(key, s, block_size=pprp.config.DEFAULT_BLOCK_SIZE):
     if padded is False:
         yield r.encrypt(chr(block_size) * block_size)
 
-def rjindael_decrypt_gen(key, s, block_size=pprp.config.DEFAULT_BLOCK_SIZE):
+def rjindael_decrypt_gen(key, s, block_size=pprp.config.DEFAULT_BLOCK_SIZE_B):
     r = rijndael_cls(key, block_size=block_size)
 
     i = 0
