@@ -4,7 +4,7 @@ import pprp.config
 
 _logger = logging.getLogger(__name__)
 
-def file_source_gen(filepath, block_size=pprp.config.DEFAULT_BLOCK_SIZE):
+def file_source_gen(filepath, block_size=pprp.config.DEFAULT_BLOCK_SIZE_B):
     with open(filepath, 'rb') as f:
         i = 0
         while 1:
@@ -18,7 +18,7 @@ def file_source_gen(filepath, block_size=pprp.config.DEFAULT_BLOCK_SIZE):
             i += 1
             offset += len(block)
 
-def data_source_gen(data, block_size=pprp.config.DEFAULT_BLOCK_SIZE):
+def data_source_gen(data, block_size=pprp.config.DEFAULT_BLOCK_SIZE_B):
     i = 0
     for offset in range(0, len(data), block_size):
         block = data[offset:offset + block_size]
